sys_traits

Module impls

Structs

Functions

  • Helper that converts a path to a string for Wasm. The wasm feature must be enabled for this to work.
  • Helper that converts a string to a path for Wasm.